# PyNeuraLogic

[Documentation]() | [Examples](#examples) | [Papers]()

PyNeuraLogic is a framework built on top of [NeuraLogic](https://github.com/GustikS/NeuraLogic) which combines relational and deep learning.

---

### General



##### Supported backends (WIP):
- [PyTorch Geometric (PyG)](https://github.com/rusty1s/pytorch_geometric)
- [DyNet](https://github.com/clab/dynet)
- [Deep Graph Library (DGL)](https://github.com/dmlc/dgl)

### Getting started

### Installation

```commandline
$ pip install neuralogic
```

### How to use

#### With PyTorch Geometric

```python

```

#### With DyNet

```python

```

#### With Deep Graph Library

```python

```

### Development

```commandline

```
